@@ -274,9 +274,9 @@ sub _parse_formdata {
     }
 
     next unless my $disposition = $part->headers->content_disposition;
-    my ($filename) = $disposition =~ /[; ]filename="?([^"]*)"?/;
+    my ($filename) = $disposition =~ /[; ]filename\s*=\s*"?([^"]*)"?/;
     next if ($upload && !defined $filename) || (!$upload && defined $filename);
-    my ($name) = $disposition =~ /[; ]name="?([^";]+)"?/;
+    my ($name) = $disposition =~ /[; ]name\s*=\s*"?([^";]+)"?/;
     if ($charset) {
       $name     = decode($charset, $name)     // $name     if $name;
       $filename = decode($charset, $filename) // $filename if $filename;
